==> kf6-kirigami-6.16.0.tgz: lib/cmake/KF6Kirigami/KF6KirigamiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6KirigamiPrimitives" for configuration "Release"
set_property(TARGET KF6KirigamiPrimitives APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrimitives PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiPrimitives.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrimitives )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrimitives "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.so.0.0" )

# Import target "KF6KirigamiDelegates" for configuration "Release"
set_property(TARGET KF6KirigamiDelegates APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDelegates PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiDelegates.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDelegates )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDelegates "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.so.0.0" )

# Import target "KF6KirigamiDialogs" for configuration "Release"
set_property(TARGET KF6KirigamiDialogs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDialogs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiDialogs.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDialogs )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDialogs "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.so.0.0" )

# Import target "KF6KirigamiLayouts" for configuration "Release"
set_property(TARGET KF6KirigamiLayouts APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiLayouts PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;Qt6::QuickControls2;KF6::KirigamiPlatform;KF6KirigamiLayoutsPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiLayouts.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiLayouts )
list(APPEND _cmake_import_check_files_for_KF6KirigamiLayouts "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.so.0.0" )

# Import target "KF6KirigamiLayoutsPrivate" for configuration "Release"
set_property(TARGET KF6KirigamiLayoutsPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiLayoutsPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;Qt6::QuickControls2;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiLayoutsPrivate.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiLayoutsPrivate.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiLayoutsPrivate )
list(APPEND _cmake_import_check_files_for_KF6KirigamiLayoutsPrivate "${_IMPORT_PREFIX}/lib/libKirigamiLayoutsPrivate.so.0.0" )

# Import target "KF6KirigamiPolyfill" for configuration "Release"
set_property(TARGET KF6KirigamiPolyfill APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPolyfill PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Quick"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPolyfill.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiPolyfill.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPolyfill )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPolyfill "${_IMPORT_PREFIX}/lib/libKirigamiPolyfill.so.0.0" )

# Import target "KF6KirigamiPrivate" for configuration "Release"
set_property(TARGET KF6KirigamiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Gui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrivate.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiPrivate.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrivate )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrivate "${_IMPORT_PREFIX}/lib/libKirigamiPrivate.so.0.0" )

# Import target "KF6Kirigami" for configuration "Release"
set_property(TARGET KF6Kirigami APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6Kirigami PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Concurrent;KF6KirigamiDelegates;KF6KirigamiPrimitives;KF6KirigamiDialogs;KF6KirigamiLayouts;KF6KirigamiPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigami.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigami.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6Kirigami )
list(APPEND _cmake_import_check_files_for_KF6Kirigami "${_IMPORT_PREFIX}/lib/libKirigami.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kf6-kirigami-6.18.0.tgz: lib/cmake/KF6Kirigami/KF6KirigamiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6KirigamiPrimitives" for configuration "Release"
set_property(TARGET KF6KirigamiPrimitives APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrimitives PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiPrimitives.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrimitives )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrimitives "${_IMPORT_PREFIX}/lib/libKirigamiPrimitives.so.0.0" )

# Import target "KF6KirigamiDelegates" for configuration "Release"
set_property(TARGET KF6KirigamiDelegates APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDelegates PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiDelegates.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDelegates )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDelegates "${_IMPORT_PREFIX}/lib/libKirigamiDelegates.so.0.0" )

# Import target "KF6KirigamiDialogs" for configuration "Release"
set_property(TARGET KF6KirigamiDialogs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiDialogs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiDialogs.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiDialogs )
list(APPEND _cmake_import_check_files_for_KF6KirigamiDialogs "${_IMPORT_PREFIX}/lib/libKirigamiDialogs.so.0.0" )

# Import target "KF6KirigamiLayouts" for configuration "Release"
set_property(TARGET KF6KirigamiLayouts APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiLayouts PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;Qt6::QuickControls2;KF6::KirigamiPlatform;KF6KirigamiLayoutsPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiLayouts.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiLayouts )
list(APPEND _cmake_import_check_files_for_KF6KirigamiLayouts "${_IMPORT_PREFIX}/lib/libKirigamiLayouts.so.0.0" )

# Import target "KF6KirigamiLayoutsPrivate" for configuration "Release"
set_property(TARGET KF6KirigamiLayoutsPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiLayoutsPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core;Qt6::Quick;Qt6::QuickControls2;KF6::KirigamiPlatform"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiLayoutsPrivate.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiLayoutsPrivate.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiLayoutsPrivate )
list(APPEND _cmake_import_check_files_for_KF6KirigamiLayoutsPrivate "${_IMPORT_PREFIX}/lib/libKirigamiLayoutsPrivate.so.0.0" )

# Import target "KF6KirigamiPolyfill" for configuration "Release"
set_property(TARGET KF6KirigamiPolyfill APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPolyfill PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Quick"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPolyfill.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiPolyfill.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPolyfill )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPolyfill "${_IMPORT_PREFIX}/lib/libKirigamiPolyfill.so.0.0" )

# Import target "KF6KirigamiTemplates" for configuration "Release"
set_property(TARGET KF6KirigamiTemplates APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiTemplates PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Core"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiTemplates.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiTemplates.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiTemplates )
list(APPEND _cmake_import_check_files_for_KF6KirigamiTemplates "${_IMPORT_PREFIX}/lib/libKirigamiTemplates.so.0.0" )

# Import target "KF6KirigamiPrivate" for configuration "Release"
set_property(TARGET KF6KirigamiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6KirigamiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Qml;Qt6::Gui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigamiPrivate.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigamiPrivate.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6KirigamiPrivate )
list(APPEND _cmake_import_check_files_for_KF6KirigamiPrivate "${_IMPORT_PREFIX}/lib/libKirigamiPrivate.so.0.0" )

# Import target "KF6Kirigami" for configuration "Release"
set_property(TARGET KF6Kirigami APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6Kirigami PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Concurrent;KF6KirigamiDelegates;KF6KirigamiPrimitives;KF6KirigamiDialogs;KF6KirigamiLayouts;KF6KirigamiPrivate;KF6KirigamiTemplates"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKirigami.so.0.0"
  IMPORTED_SONAME_RELEASE "libKirigami.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF6Kirigami )
list(APPEND _cmake_import_check_files_for_KF6Kirigami "${_IMPORT_PREFIX}/lib/libKirigami.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
